@@ -1,18 +1,18 @@
 package Template::Liquid::Utility;
 use strict;
 use warnings;
-our $VERSION         = '1.0.13';
+our $VERSION         = '1.0.14';
 our $FilterSeparator = qr[\s*\|\s*]o;
 my $ArgumentSeparator = qr[,]o;
 our $FilterArgumentSeparator    = qr[\s*:\s*]o;
 our $VariableAttributeSeparator = qr[\.]o;
-our $TagStart                   = qr[{%\s*]o;
-our $TagEnd                     = qr[\s*%}]o;
+our $TagStart                   = qr[(?:\s*{%-\s*|{%\s*)]o;
+our $TagEnd                     = qr[(?:\s*-%}\s+?|\s*%})]o;
 our $VariableSignature          = qr{\(?[\w\-\.\[\]]\)?}o;
 my $VariableSegment = qr[[\w\-]\??]ox;
-our $VariableStart = qr[\{\{\s*]o;
-our $VariableEnd   = qr[\s*}}]o;
-my $VariableIncompleteEnd = qr[}}?];
+our $VariableStart = qr[(?:\s*\{\{-\s*|\{\{-?\s*)]o;
+our $VariableEnd   = qr[(?:\s*-?}}\s*?|\s*}})]o;
+my $VariableIncompleteEnd = qr[(?:\s*-}}?\s*|}})];
 my $QuotedString          = qr/"(?:[^"\\]|\\.)*"|'(?:[^'\\]|\\.)*'/o;
 my $QuotedFragment = qr/${QuotedString}|(?:[^\s,\|'"]|${QuotedString})+/o;
 my $StrictQuotedFragment = qr/"[^"]+"|'[^']+'|[^\s,\|,\:,\,]+/o;
@@ -26,25 +26,20 @@ our $Expression    = qr/(?:${QuotedFragment}(?:${SpacelessFilter})*)/o;
 our $TagAttributes = qr[(\w+)(?:\s*\:\s*(${QuotedFragment}))?]o;
 my $AnyStartingTag = qr[\{\{|\{\%]o;
 my $PartialTemplateParser
-    = qr[${TagStart}.*?${TagEnd}|${VariableStart}.*?${VariableIncompleteEnd}]o;
-my $TemplateParser = qr[(${PartialTemplateParser}|${AnyStartingTag})]o;
-our $VariableParser = qr[^
-                            ${VariableStart}                        # {{
-                                ([\w\.]+)    #   name
-                                (?:\s*\|\s*(.+)\s*)?                 #   filters
-                            ${VariableEnd}                          # }}
-                            $]ox;
+    = qr[${TagStart}.+?${TagEnd}|${VariableStart}.+?${VariableIncompleteEnd}]os;
+my $TemplateParser = qr[(${PartialTemplateParser}|${AnyStartingTag})]os;
+our $VariableParser
+    = qr[${VariableStart}([\w\.]+)(?:\s*\|\s*(.+)\s*)?${VariableEnd}$]so;
 our $VariableFilterArgumentParser
-    = qr[\s*,\s*(?=(?:[^\']*\'[^\']*\')*(?![^\']*\'))]o;
+    = qr[\s*,\s*(?=(?:[^\']*\'[^\']*\')*(?![^\']*\'))]os;
 our $TagMatch = qr[^${Template::Liquid::Utility::TagStart}   # {%
                                 (.+?)                              # etc
                               ${Template::Liquid::Utility::TagEnd} # %}
-                             $]ox;
-our $VarMatch = qr[^
-                    ${Template::Liquid::Utility::VariableStart} # {{
+                             $]sox;
+our $VarMatch = qr[^${Template::Liquid::Utility::VariableStart} # {{
                         (.+?)                           #  stuff + filters?
                     ${Template::Liquid::Utility::VariableEnd}   # }}
-                $]ox;
+                $]sox;
 
 sub tokenize {
     map { $_ ? $_ : () } split $TemplateParser, shift || '';
